==> indigitall_flutter_plugin-0.1.1.tar.gz: lib/push/models/Topic.dart <==
import 'dart:convert';

class Topic {
  static const String _JSON_CODE = "code";
  static const String _JSON_NAME = "name";
  static const String _JSON_VISIBLE = "visible";
  static const String _JSON_SUBSCRIBED = "subscribed";

  String? code;
  String? name;
  bool visible = false;
  bool subscribed = false;

  Topic(Map? map) {
    map?.forEach((key, value) {
      switch (key) {
        case _JSON_CODE:
          code = value.toString();
          break;
        case _JSON_NAME:
          name = value.toString();
          break;
        case _JSON_VISIBLE:
          visible = value.toString() == "true";
          break;
        case _JSON_SUBSCRIBED:
          subscribed = value.toString() =="true";
          break;
      }
    });
  }

  static List<Topic> createArray(dynamic topics) {
    List<dynamic> list = topics;
    List<Topic> topicList = [];
    for (int i = 0; i < list.length; i++){
      Topic? topic = new Topic(null);
      list[i].forEach((key, value) {
        if (key == _JSON_CODE) topic.code = value.toString();
        if (key == _JSON_NAME) topic.name = value.toString();
        if (key == _JSON_VISIBLE) topic.visible = value.toString() == "true";
        if (key == _JSON_SUBSCRIBED) topic.subscribed = value.toString() == "true";
      });
      topicList.add(topic);
    }
    return topicList;
  }

  Map toMap(){
    Map map = Map();
    if (code != null) map[_JSON_CODE] = code;
    if (name != null) map[_JSON_NAME] = name;
    map[_JSON_VISIBLE] = visible;
    map[_JSON_SUBSCRIBED] = subscribed;
    return map;
  }

  @override
  String toString() {
    return json.encode(toMap());
  }
}

==> indigitall_flutter_plugin-0.1.2.tar.gz: lib/push/models/Topic.dart <==
import 'dart:convert';

class Topic {
  static const String _JSON_CODE = "code";
  static const String _JSON_NAME = "name";
  static const String _JSON_VISIBLE = "visible";
  static const String _JSON_SUBSCRIBED = "subscribed";

  String? code;
  String? name;
  bool visible = false;
  bool subscribed = false;

  /// Constructor of [Topic]
  Topic(Map? map) {
    map?.forEach((key, value) {
      switch (key) {
        case _JSON_CODE:
          code = value.toString();
          break;
        case _JSON_NAME:
          name = value.toString();
          break;
        case _JSON_VISIBLE:
          visible = value.toString() == "true";
          break;
        case _JSON_SUBSCRIBED:
          subscribed = value.toString() == "true";
          break;
      }
    });
  }

  /// Get a list of [topic]
  static List<Topic> createArray(dynamic topics) {
    List<dynamic> list = topics;
    List<Topic> topicList = [];
    for (int i = 0; i < list.length; i++) {
      Topic? topic = new Topic(null);
      list[i].forEach((key, value) {
        if (key == _JSON_CODE) topic.code = value.toString();
        if (key == _JSON_NAME) topic.name = value.toString();
        if (key == _JSON_VISIBLE) topic.visible = value.toString() == "true";
        if (key == _JSON_SUBSCRIBED)
          topic.subscribed = value.toString() == "true";
      });
      topicList.add(topic);
    }
    return topicList;
  }

  /// Conversion to [Map]
  Map toMap() {
    Map map = Map();
    if (code != null) map[_JSON_CODE] = code;
    if (name != null) map[_JSON_NAME] = name;
    map[_JSON_VISIBLE] = visible;
    map[_JSON_SUBSCRIBED] = subscribed;
    return map;
  }

  /// Conversion to [String]
  @override
  String toString() {
    return json.encode(toMap());
  }
}
